package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.36.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.36.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````$"D```````!``````````%#!````
M`````````$``.``-`$``'0`<``8````$````0`````````!``````````$``
M````````V`(```````#8`@````````@``````````P````0````8`P``````
M`!@#````````&`,````````<`````````!P``````````0`````````!````
M!````````````````````````````````````'@9````````>!D`````````
M$`````````$````%`````"``````````(``````````@````````/4(`````
M```]0@`````````0`````````0````0`````<`````````!P`````````'``
M``````!P2````````'!(`````````!`````````!````!@```,B[````````
MR,L```````#(RP```````%@$````````@`0`````````$`````````(````&
M````V+L```````#8RP```````-C+``````````(``````````@````````@`
M````````!`````0````X`P```````#@#````````.`,````````P````````
M`#``````````"``````````$````!````&@#````````:`,```````!H`P``
M`````$0`````````1``````````$`````````%/E=&0$````.`,````````X
M`P```````#@#````````,``````````P``````````@`````````4.5T9`0`
M```@L0```````""Q````````(+$```````#T`````````/0`````````!```
M``````!1Y71D!@``````````````````````````````````````````````
M```````````0`````````%+E=&0$````R+L```````#(RP```````,C+````
M````.`0````````X!`````````$`````````+VQI8C8T+VQD+6QI;G5X+7@X
M-BTV-"YS;RXR```````$````(`````4```!'3E4``@``P`0````#````````
M``*``,`$`````0`````````$````%`````,```!'3E4`Q>6>T>+/X?;%`'G%
M_J"BX?4D[W$$````$`````$```!'3E4```````,````"```````````````1
M````0P````0````(````(!`0``5`!(0H`@`$@(8`A(()```)(`0(B(`10;H`
M`@@`````0P```$8```!)````2@```%$```!2````4P````````!5````5@``
M`%<```!8````6@```%P``````````````&[%WQ_.WD<M:W^:?"[%F[;49-1\
M(?_D#MEQ6!SB1\8!L@&+;ZQ+X\!"^M>'PN4_++KCDGS[H6Q@:PE#UF>OS&9"
M1=7LB0=PTS-BV^T5C"7,#3J7"WZIG)O19<YMX*<""FL:GE"CX/M)````````
M`````````````````````````````!`"```2````````````````````````
M`*8"```2`````````````````````````)`"```2````````````````````
M`````(P````1`````````````````````````/<!```2````````````````
M`````````#X!```2`````````````````````````&X"```2````````````
M`````````````+,!```2``````````````````````````$````@````````
M`````````````````$L"```2`````````````````````````&<````2````
M`````````````````````(L"```2`````````````````````````)0````2
M`````````````````````````/`!```2`````````````````````````$("
M```2`````````````````````````)8"```2````````````````````````
M`-(````2`````````````````````````.(````2````````````````````
M`````#`!```2`````````````````````````&0!```2````````````````
M`````````(H````1`````````````````````````&T#```2````````````
M`````````````!`````@`````````````````````````"@"```2````````
M`````````````````!4"```2`````````````````````````+T````2````
M`````````````````````"P````@`````````````````````````)T````2
M`````````````````````````*L````2`````````````````````````!H"
M```2`````````````````````````.@````6````````````````````````
M`/L````2`````````````````````````,8!```2````````````````````
M`````!8!```2`````````````````````````#,"```2````````````````
M`````````(X!```2`````````````````````````'P"```2````````````
M`````````````)T!```2`````````````````````````$4!```2````````
M`````````````````"<!```2`````````````````````````%0!```2````
M`````````````````````'(!```2``````````````````````````("```2
M`````````````````````````%8"```2`````````````````````````'D!
M```2`````````````````````````,<"```2````````````````````````
M`'D````2`````````````````````````(<!```2````````````````````
M`````(`!```2`````````````````````````)P````2````````````````
M`````````)8!```2`````````````````````````+("```2````````````
M`````````````.0!```2`````````````````````````(,"```2````````
M`````````````````-D````2`````````````````````````,0````2````
M`````````````````````&<"```1`````````````````````````-<!```1
M`````````````````````````*0````2`````````````````````````%P!
M```2``````````````````````````L!```2````````````````````````
M`*0!```2`````````````````````````$8````2````````````````````
M`````&L!```2`````````````````````````+,````2````````````````
M`````````%`"```2`````````````````````````'8#```2`!``H%(`````
M```D`0```````,L#```2`!``P%<````````X"````````%,````2`!```"<`
M```````0`@```````.T"```2`!``T$<````````)``````````L#```2`!``
M`&`````````@`@```````/$#```2`!``X$<````````2`@```````+$#```0
M`!H`(-```````````````````/X"```2`!```$H````````F`````````"$#
M```2`!``D%````````!\`````````((#```1`!(``'`````````$````````
M`)X#```2`!``T%,```````"?`0```````*D#```2`!``P$8````````I````
M`````,8#```0`!H`2-```````````````````-\#```2`!``0%$````````+
M`0```````)$#```0`!D``-```````````````````$4#```2`!``,$H`````
M``!!`0```````-@#```0`!D`(-```````````````````/X#```1`!D`&-``
M```````(`````````)<#```2`!``$"D````````F`````````+T#```2`!``
M4%(```````!)`````````),#```@`!D``-```````````````````%L#```2
M`!``$%$````````A`````````%@````B`````````````````````````"\#
M```2`!``\$8```````#2`````````%$#```2`!``<%4```````!+`@``````
M``@$```2`!``@$L````````$!0````````!?7V=M;VY?<W1A<G1?7P!?251-
M7V1E<F5G:7-T97)434-L;VYE5&%B;&4`7TE435]R96=I<W1E<E1-0VQO;F54
M86)L90!?7VQI8F-?<W1A<G1?;6%I;@!?7V-X85]F:6YA;&EZ90!?7W)E9VES
M=&5R7V%T9F]R:P!?7W-T86-K7V-H:U]F86EL`%]?96YV:7)O;@!S=')N8VUP
M`&QS=&%T-C0`86-C97-S`&]P96YD:7(`<F5A9&1I<C8T`'-T<FQE;@!?7W-P
M<FEN=&9?8VAK`'5N;&EN:P!C;&]S961I<@!R;61I<@!03%]C=7)R96YT7V-O
M;G1E>'0`8F]O=%]$>6YA3&]A9&5R`%!E<FQ?;F5W6%,`4&5R;%]N97=84U]F
M;&%G<P!R96%D;&EN:P!097)L7W-V7W-E='!V`&UE;6-H<@!097)L7W-V7W-E
M='!V;@!M96UM;W9E`')E86QL;V,`9V5T<&ED`&UE;6-P>0!S=')C:'(`<W1R
M9'5P`'-T<G1O:P!S=')C;7``<W1R<F-H<@!G971U:60`<W1R<W1R`%!E<FQ?
M<WES7VEN:70S`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7V%T9F]R:U]L;V-K
M`%!,7V1O7W5N9'5M<`!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]P87)S90!P
M97)L7V1E<W1R=6-T`'!E<FQ?9G)E90!097)L7W-Y<U]T97)M`'!E<FQ?86QL
M;V,`<&5R;%]C;VYS=')U8W0`<&5R;%]R=6X`97AI=`!M:V1I<@!?7V5R<FYO
M7VQO8V%T:6]N`'-T9&5R<@!?7V9P<FEN=&9?8VAK`&]P96XV-`!L<V5E:S8T
M`')E860`8VQO<V4`4&5R;%]G=E]F971C:'!V`%!E<FQ?9V5T7W-V`%!E<FQ?
M8W)O86M?;F]C;VYT97AT`%!E<FQ?;6=?<V5T`&QI8G!E<FPN<V\N-2XS-@!L
M:6)C+G-O+C8`<&%R7V-U<G)E;G1?97AE8P!P87)?8F%S96YA;64`6%-?26YT
M97)N86QS7U!!4E]"3T]4`'!A<E]E;G9?8VQE86X`<&%R7V-U<G)E;G1?97AE
M8U]P<F]C`'!A<E]D:7)N86UE`'-H85]F:6YA;`!G971?=7-E<FYA;65?9G)O
M;5]G971P=W5I9`!P87)?8VQE86YU<`!?24]?<W1D:6Y?=7-E9`!?7V1A=&%?
M<W1A<G0`<VAA7W5P9&%T90!X<U]I;FET`%]?8G-S7W-T87)T`'-H85]I;FET
M`%]E;F0`<&%R7VUK=&UP9&ER`%]E9&%T80!P87)?<V5T=7!?;&EB<&%T:`!P
M87)?9FEN9'!R;V<`;7E?<&%R7W!L`'!A<E]I;FET7V5N=@!'3$E"0U\R+C$T
M`$=,24)#7S(N,S0`1TQ)0D-?,BXT`$=,24)#7S(N,S,`1TQ)0D-?,BXS+C(`
M1TQ)0D-?,BXS+C0`1TQ)0D-?,BXR+C4````!``$``@`"``$``@`#``$``0`"
M``0``@`"``(``0`!``(``@`!``(``@`"``$``0`"``(``0`%``(``0`!``$`
M`0`!``$``@`"``(``0`"``(``@`!``(``@`!``8``@`"``4``@`!``$``@`"
M``,``@`!``(``@`!``$`!P`(``(``@`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``(``0`!``$````!``<`XP(``!``````
M````E)&6!@``"``5!```$````+21E@8```<`(`0``!`````4:6D-```&`"L$
M```0````LY&6!@``!0`U!```$````'(9:0D```0`0`0``!````!T&6D)```#
M`$P$```0````=1II"0```@!8!````````,C+````````"`````````#P*0``
M`````-#+````````"`````````"P*0````````C0````````"``````````(
MT````````!C0````````"`````````#8<@```````*#/````````!@````0`
M`````````````*C/````````!@````@``````````````+#/````````!@``
M``D``````````````+C/````````!@```!<``````````````,#/````````
M!@```!L``````````````,C/````````!@```%D``````````````-#/````
M````$@```!\``````````````-C/````````!@```"```````````````.#/
M````````!@```"$``````````````.C/````````!@```#D`````````````
M`/#/````````!@```#H``````````````/C/````````!@```#\`````````
M`````/#-````````!P````$``````````````/C-````````!P````(`````
M``````````#.````````!P````,```````````````C.````````!P````4`
M`````````````!#.````````!P````8``````````````!C.````````!P``
M``<``````````````"#.````````!P````H``````````````"C.````````
M!P````L``````````````##.````````!P````P``````````````#C.````
M````!P````T``````````````$#.````````!P````X``````````````$C.
M````````!P````\``````````````%#.````````!P```!``````````````
M`%C.````````!P```!$``````````````&#.````````!P```!(`````````
M`````&C.````````!P```!,``````````````'#.````````!P```!0`````
M`````````'C.````````!P```!8``````````````(#.````````!P```!@`
M`````````````(C.````````!P```!D``````````````)#.````````!P``
M`!H``````````````)C.````````!P```!P``````````````*#.````````
M!P```!T``````````````*C.````````!P```!X``````````````+#.````
M````!P```"(``````````````+C.````````!P```",``````````````,#.
M````````!P```"0``````````````,C.````````!P```"4`````````````
M`-#.````````!P```"8``````````````-C.````````!P```"<`````````
M`````.#.````````!P```"@``````````````.C.````````!P```"D`````
M`````````/#.````````!P```"H``````````````/C.````````!P```"L`
M``````````````#/````````!P```"P```````````````C/````````!P``
M`"T``````````````!#/````````!P```"X``````````````!C/````````
M!P```"\``````````````"#/````````!P```#```````````````"C/````
M````!P```#$``````````````##/````````!P```#(``````````````#C/
M````````!P```#,``````````````$#/````````!P```#0`````````````
M`$C/````````!P```#4``````````````%#/````````!P```#8`````````
M`````%C/````````!P```#<``````````````&#/````````!P```#@`````
M`````````&C/````````!P```#L``````````````'#/````````!P```#P`
M`````````````'C/````````!P```#T``````````````(#/````````!P``
M`#X``````````````(C/````````!P```$```````````````)#/````````
M!P```$$``````````````)C/````````!P```$(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#S#Q[Z2(/L"$B+!:&O``!(A<!T`O_02(/$",,``````/\UNJT``/+_);NM
M```/'P#S#Q[Z:`````#RZ>'___^0\P\>^F@!````\NG1____D/,/'OIH`@``
M`/+IP?___Y#S#Q[Z:`,```#RZ;'___^0\P\>^F@$````\NFA____D/,/'OIH
M!0```/+ID?___Y#S#Q[Z:`8```#RZ8'___^0\P\>^F@'````\NEQ____D/,/
M'OIH"````/+I8?___Y#S#Q[Z:`D```#RZ5'___^0\P\>^F@*````\NE!____
MD/,/'OIH"P```/+I,?___Y#S#Q[Z:`P```#RZ2'___^0\P\>^F@-````\ND1
M____D/,/'OIH#@```/+I`?___Y#S#Q[Z:`\```#RZ?'^__^0\P\>^F@0````
M\NGA_O__D/,/'OIH$0```/+IT?[__Y#S#Q[Z:!(```#RZ<'^__^0\P\>^F@3
M````\NFQ_O__D/,/'OIH%````/+IH?[__Y#S#Q[Z:!4```#RZ9'^__^0\P\>
M^F@6````\NF!_O__D/,/'OIH%P```/+I<?[__Y#S#Q[Z:!@```#RZ6'^__^0
M\P\>^F@9````\NE1_O__D/,/'OIH&@```/+I0?[__Y#S#Q[Z:!L```#RZ3'^
M__^0\P\>^F@<````\NDA_O__D/,/'OIH'0```/+I$?[__Y#S#Q[Z:!X```#R
MZ0'^__^0\P\>^F@?````\NGQ_?__D/,/'OIH(````/+IX?W__Y#S#Q[Z:"$`
M``#RZ=']__^0\P\>^F@B````\NG!_?__D/,/'OIH(P```/+IL?W__Y#S#Q[Z
M:"0```#RZ:']__^0\P\>^F@E````\NF1_?__D/,/'OIH)@```/+I@?W__Y#S
M#Q[Z:"<```#RZ7']__^0\P\>^F@H````\NEA_?__D/,/'OIH*0```/+I4?W_
M_Y#S#Q[Z:"H```#RZ4']__^0\P\>^F@K````\NDQ_?__D/,/'OIH+````/+I
M(?W__Y#S#Q[Z:"T```#RZ1']__^0\P\>^F@N````\ND!_?__D/,/'OIH+P``
M`/+I\?S__Y#S#Q[Z:#````#RZ>'\__^0\P\>^F@Q````\NG1_/__D/,/'OIH
M,@```/+IP?S__Y#S#Q[Z:#,```#RZ;'\__^0\P\>^F@T````\NFA_/__D/,/
M'OIH-0```/+ID?S__Y#S#Q[Z\O\E+:P```\?1```\P\>^O+_)46J```/'T0`
M`/,/'OKR_R4]J@``#Q]$``#S#Q[Z\O\E-:H```\?1```\P\>^O+_)2VJ```/
M'T0``/,/'OKR_R4EJ@``#Q]$``#S#Q[Z\O\E':H```\?1```\P\>^O+_)16J
M```/'T0``/,/'OKR_R4-J@``#Q]$``#S#Q[Z\O\E!:H```\?1```\P\>^O+_
M)?VI```/'T0``/,/'OKR_R7UJ0``#Q]$``#S#Q[Z\O\E[:D```\?1```\P\>
M^O+_)>6I```/'T0``/,/'OKR_R7=J0``#Q]$``#S#Q[Z\O\EU:D```\?1```
M\P\>^O+_)<VI```/'T0``/,/'OKR_R7%J0``#Q]$``#S#Q[Z\O\EO:D```\?
M1```\P\>^O+_);6I```/'T0``/,/'OKR_R6MJ0``#Q]$``#S#Q[Z\O\EI:D`
M``\?1```\P\>^O+_)9VI```/'T0``/,/'OKR_R65J0``#Q]$``#S#Q[Z\O\E
MC:D```\?1```\P\>^O+_)86I```/'T0``/,/'OKR_R5]J0``#Q]$``#S#Q[Z
M\O\E=:D```\?1```\P\>^O+_)6VI```/'T0``/,/'OKR_R5EJ0``#Q]$``#S
M#Q[Z\O\E7:D```\?1```\P\>^O+_)56I```/'T0``/,/'OKR_R5-J0``#Q]$
M``#S#Q[Z\O\E1:D```\?1```\P\>^O+_)3VI```/'T0``/,/'OKR_R4UJ0``
M#Q]$``#S#Q[Z\O\E+:D```\?1```\P\>^O+_)26I```/'T0``/,/'OKR_R4=
MJ0``#Q]$``#S#Q[Z\O\E%:D```\?1```\P\>^O+_)0VI```/'T0``/,/'OKR
M_R4%J0``#Q]$``#S#Q[Z\O\E_:@```\?1```\P\>^O+_)?6H```/'T0``/,/
M'OKR_R7MJ```#Q]$``#S#Q[Z\O\EY:@```\?1```\P\>^O+_)=VH```/'T0`
M`/,/'OKR_R75J```#Q]$``#S#Q[Z\O\ES:@```\?1```\P\>^O+_)<6H```/
M'T0``/,/'OKR_R6]J```#Q]$``#S#Q[Z\O\EM:@```\?1```\P\>^O+_):VH
M```/'T0``/,/'OKR_R6EJ```#Q]$``#S#Q[Z\O\EG:@```\?1```\P\>^E53
M2(/L.(E\)!Q(C7PD'$B)="002(UT)!!(B50D"$B-5"0(9$B+!"4H````2(E$
M)"@QP.B$____2(LU9:@``$B+/9:H``!(B?+HSCH``$B+!9>H``"`.``/A!@!
M``!(BP5GJ```9$B+`("(*@0```.+1"0<C7@$C5@#2&/_2,'G`^C&_O__2(M,
M)!!$BT0D'$B)QDB)!:*H``!(BP%(B09(C06(20``2(E&"$B-!6*H``!(BP!(
MB4802(T%<DD``$B)1AA!@_@!#XXE`0``2(/!"$&#P`.X!````)!(BSE(8]"#
MP`%(@\$(2(D\UD0YP'7J2)A(BSTQJ```2(GQB=I(QP3&`````$4QP$B--2H;
M``#HM?O__XG#A<`/A(4```!(BST$J```2(UL)"3H>OW__S'`2(GN2(T]84@`
M`.@I&```2(7`='%(BSW=IP``Z$C[___HL_S__TB+1"0H9$@K!"4H````#X6:
M````2(/$.(G86UW#Z$'\__](B06JIP``2(G'2(7`='/HG?S__TB+!3:G``!D
M2(L0QH+7"0```.F__O__2(L]?Z<``.B:^___B</I:/___TB+/72G``!(A?]T
M"NC2*0``Z7G___](C3U^1P``2(GNZ(X7``!(B05/IP``2(G'2(7`#X17____
MZ]*X!````.GU_O__OP$```#H]?K__^C@_/__\P\>^C'M28G17DB)XDB#Y/!0
M5$4QP#')2(T]T?W___\5PZ8``/1F+@\?A```````2(T]V:8``$B-!=*F``!(
M.?AT%4B+!5ZF``!(A<!T"?_@#Q^``````,,/'X``````2(T]J:8``$B--:*F
M``!(*?Y(B?!(P>X_2,'X`T@!QDC1_G042(L%):8``$B%P'0(_^!F#Q]$``##
M#Q^``````/,/'OJ`/66F````=2M52(,]`J8```!(B>5T#$B+/3:F``#HN?G_
M_^AD____Q@4]I@```5W##Q\`PP\?@`````#S#Q[ZZ7?___\/'X``````05=(
MB?Y,C4<X059!54%455-(@>R8`@``9$B+!"4H````2(F$)(@"```QP$B)XDR-
MC"2`````2(G7#Q^``````$&+`$V+$$B#QQ!)@\`(#\B)P$R)T4B)1_!,B=!(
MP>D@2,'H*$G!ZC@E`/\``$P)T$F)RDC!X0A)P>(8@>$``/\`18G23`G02`G(
M2(E'^$PYSW6M9@]O1"009@]O7"0@2(U$)&A(@<)H`@``9@]O5"0P9@]O+2>&
M```/'X``````\P]O"&8/;^)F#V]0V$B#P!!F#^]`B&8/[\IF#^_!9@]OR&8/
M<]`?9@]S\0%F#^O!9@_;Q0\I0`AF#V_#9@]OW$@YT'6[3(L.3(M>$$B+?B!(
MBUX83(G(3(G*2(MN"$B+3"0(2,'J&TC!X`5("=`#!"1(C8P+F7F"6HV4.)EY
M@EI,B=A(,=A((>A(,=B-/`)(B>I(B>A(P>@"2,'B'DF)^D@)PDR)V$G!ZAM!
MB=!,,<!,(<A,,=A(`<A(B?E(P>$%3`G13(M4)!!$C20(3(G(3(G)2,'I`DC!
MX!Y/C903F7F"6DV)Y4@)R$G![1M(,<*)P4@A^DPQPDP!TDV)XDG!X@5-">I,
MBVPD&$$!TDB)^DC![P)(P>(>18G23XV$*)EY@EI("?I-B=5(,=")UTPAX$G!
M[1M(,<A,`<!-B=!)P>`%30GH3(ML)"!!`<!,B>!)P>P"2,'@'D6)P$J-C"F9
M>8):3`G@38G%2#'"2<'M&T&)Q$PATD@Q^D@!RDR)P4C!X05,">E,BVPD*`'1
M3(G22<'J`DC!XAZ)R4J-O"^9>8):3`G228G-2#'02<'M&T&)TDPAP$PQX$@!
M^$B)STC!YP5,">],BVPD,`''3(G`2<'H`DC!X!Z)_T^-I"R9>8):3`G`28G]
M2#'"2<'M&T&)P$@ARDPQTDP!XDF)_$G!Y`5-">Q,BVPD.$$!U$B)RDC!Z0)(
MP>(>18GD3XV4*IEY@EI("<I-B>5(,=!)P>T;B=%((?A,,<!,`=!-B>))P>(%
M30GJ3(ML)$!!`<)(B?A(P>\"2,'@'D6)TD^-A"B9>8):2`GX38G52#'"2<'M
M&XG'3"'B2#'*3`'"38G02<'@!4T)Z$R+;"1(00'03(GB2<'L`DC!XAY%B<!*
MC8PIF7F"6DP)XDV)Q4@QT$G![1M!B=1,(=!(,?A(`<A,B<%(P>$%3`GI3(ML
M)%`!P4R)T$G!Z@)(P>`>B<E*C;POF7F"6DP)T$F)S4@QPDG![1M!B<),(<),
M,>)(`?I(B<](P><%3`GO3(ML)%@!UTR)PDG!Z`)(P>(>B?]/C:0LF7F"6DP)
MPDF)_4@QT$G![1M!B=!((<A,,=!,`>!)B?Q)P>0%30GL3(ML)&!!`<1(B<A(
MP>`>2,'I`D6)Y$^-E"J9>8):2`G(38GE2#'"2<'M&XG!2"'Z3#'"3`'238GB
M2<'B!4T)ZDR+;"1H00'22(GZ2,'O`DC!XAY%B=)/C80HF7F"6D@)^DV)U4@Q
MT$G![1N)UTPAX$@QR$P!P$V)T$G!X`5-">A,BVPD<$$!P$R)X$G![`)(P>`>
M18G`2HV,*9EY@EI,">!-B<5(,<))P>T;08G$3"'22#'Z2`'*3(G!2,'A!4P)
MZ4R+;"1X`=%,B=)(P>(>2<'J`HG)2HV\+YEY@EI,"=))B<U(,=!)P>T;08G2
M3"'`3#'@2`'X2(G/2,'G!4P)[TR+K"2``````<=,B<!)P>@"2,'@'HG_3XVD
M+)EY@EI,"<!)B?U(,<))P>T;08G`2"'*3#'23`'B28G\2<'D!4T)[$:-+")(
MB<I(P>D"3(ND)(@```!(P>(>2`G*3XV4(IEY@EI-B>Q(,=!)P>P;B=%((?A,
M,<!,`=!-B>I)P>(%30GB3(ND))````!!`<)(B?A(P>`>2,'O`D6)TD^-A""9
M>8):2`GX38G42#'"2<'L&XG'3"'J2#'*3`'"38G02<'@!4T)X$6)P$P!PDV)
MZ$G![0))P>`>08G430GH3(NL))@```!,,<!,(=!*C8PIF7F"6DV)Y4@Q^$G!
M[1M(`<A,B>%(P>$%3`GIB<E(`<A,B=%)P>H"2,'A'D&)Q4P)T4V)PD6)P$DQ
MRD0QTDR+E"2@````2HV\%Z'KV6Y-B>I(`==,B>I)P>H;2,'B!4P)THG22`'7
M3(GB2,'B'DG![`)!B?I,`X0DJ````$P)XDF)S(G)2`.,)+````!),=1$,>!-
MC:0`H>O9;DR)T$V)T$G!Z!M(P>`%3`G`B<!)`<1,B>A)P>T"2,'@'D6)X$P)
MZ$F)U8G22`.4)+@```!),<5$,>],C:PYH>O9;DR)P4R)QTC![QM(P>$%2`GY
MB<E)`<U,B=%)P>H"2,'A'D2)[TP)T4F)PHG`23'*13'B3HVD$J'KV6Y(B?I)
MB?I)P>H;2,'B!4P)THG220'43(G"2<'H`DC!XAY%B>),"<))B<A(`X0DP```
M`(G)23'02`.,),@```!%,>A.C:P`H>O9;DR)T$V)T$G!Z!M(P>`%3`G`B<!)
M`<5(B?A(P>\"2,'@'D6)Z$@)^$B)UXG22`.4)-````!(,<=$,>=,C:0YH>O9
M;DR)P4R)QTC![QM(P>$%2`GYB<E)`<Q,B=%)P>H"2,'A'D2)YTP)T4F)PHG`
M2`.$)-@```!),<I%,>I.C:P2H>O9;DB)^DF)^DG!ZAM(P>(%3`G2B=))`=5,
MB<))P>@"2,'B'D6)ZDP)PDF)R(G)23'02`.,).````!%,>!.C:0`H>O9;DR)
MT$V)T$G!Z!M(P>`%3`G`B<!)`<1(B?A(P>\"2,'@'D6)X$@)^$B)UXG22`.4
M).@```!(,<=$,>],C:PYH>O9;DR)P4R)QTC![QM(P>$%2`GYB<E)`<U,B=%)
MP>H"2,'A'D2)[TP)T4F)PHG`2`.$)/````!),<I%,>).C:02H>O9;DB)^DF)
M^DG!ZAM(P>(%3`G2B=))`=1,B<))P>@"2,'B'D6)XDP)PDF)R(G)23'013'H
M3HVL`*'KV6Y,B=!-B=!(P>`%2<'H&T@#C"3X````3`G`B<!)`<5(B?A(P>\"
M2,'@'D6)Z$@)^$B)UXG22`.4)``!``!(,<=$,>=,C:0YH>O9;DR)P4R)QTC!
M[QM(P>$%2`GYB<E)`<Q,B=%)P>H"2,'A'D2)YTP)T4F)PHG`2`.$)`@!``!)
M,<I%,>I.C:P2H>O9;DB)^DF)^DG!ZAM(P>(%3`G2B=))`=5,B<))P>@"2,'B
M'D6)ZDP)PDF)R(G)23'013'@3HVD`*'KV6Y,B=!-B=!)P>@;2,'@!4P)P$@#
MC"00`0``B<!)`<1(B?A(P>\"2,'@'D6)X$@)^$B)UXG22`.4)!@!``!(,<=$
M,>],C:PYH>O9;DR)P4R)QTC![QM(P>$%2`GYB<E)`<U,B=%)P>H"2,'A'D2)
M[TP)T4F)PHG`2`.$)"`!``!),<I%,>).C:02H>O9;DB)^DF)^DG!ZAM(P>(%
M3`G2B=))`=1,B<))P>@"2,'B'D6)XDP)PDF)R(G)23'013'H3HVL`*'KV6Y,
MB=!-B=!)P>@;2,'@!4P)P(G`20'%2(GX2,'@'DC![P)%B>A(`XPD*`$``$@)
M^$B)UXG22`.4)#`!``!(,<=$,>=-B<1(C8PYH>O9;DR)QTG![!M(P><%3`GG
M38G42<'J`DG!Y!Z)_TT)U$F)PD@!^8G`33'BB<](`X0D.`$``$4QZDF)_4Z-
ME!*AZ]EN2(GZ2<'M&TC!X@5,">I!`=),B<))P>@"2,'B'D6)TDP)PDV)X$6)
MY$DQT$F)UD&)U40QP4V)T$B-C`BAZ]EN3(G02<'H&TC!X`5,"<!$C00!2(GY
M2,'O`KC<O!N/2,'A'D@)^4D)SHG/2"'Z32'620G62(N4)$`!``!(`<),`>)-
MB<1,`?)-B<9)P>0%2<'N&TT)]$$!U$R)TDG!Z@)(P>(>18GD3`G22`G128G6
M08G222'^3"'!3`GQ3(NT)$@!``!)`<9-`?5-B>9,`>E-B>5)P>X;2<'E!4T)
M]4F)UD$!S4R)P4G!Z`)(P>$>18GM3`G!08G(20G.32'F3"'"3`GR3(NT)%`!
M``!)`<9,`?=-B>Y(`?I,B>])P>X;2,'G!4P)]P'73(GB2<'L`DC!XAZ)_TP)
MXD@)T4F)UD&)U$TAQDPAZ4P)\4R+M"18`0``20'&30'R28G^3`'128GZ2<'N
M&TG!X@5-"?))B=9!`<I,B>E)P>T"2,'A'D6)TDP)Z4&)S4D)SDDA_DPAZDP)
M\DR+M"1@`0``20'&30'P38G63`'"38G02<'@!4G![AM-"?!!`=!(B?I(P>\"
M2,'B'D6)P$@)^D@)T4F)UHG732'N3"'13`GQ3(NT)&@!``!)`<9-`?1-B<9,
M`>%-B<1)P>X;2<'D!4T)]$F)UD$!S$R)T4G!Z@)(P>$>18GD3`G108G*20G.
M32'&3"'23`GR3(NT)'`!``!)`<9-`?5-B>9,`>I-B>5)P>X;2<'E!4T)]4$!
MU4R)PDC!XAY)P>@"18GM3`G"2`G128G608G032'63"'A3`GQ3(NT)'@!``!)
M`<9,`?=-B>Y(`?E,B>])P>X;2,'G!4P)]TF)U@'/3(GA2<'L`DC!X1Z)_TP)
MX4&)S$D)SDTA[DPAXDP)\DR+M"2``0``20'&30'R28G^3`'228GZ2<'N&TG!
MX@5-"?)!`=),B>I)P>T"2,'B'D6)TDP)ZD@)T4F)UD&)U4@A^4TAYDP)\4R+
MM"2(`0``20'&30'P38G63`'!38G02<'N&TG!X`5-"?!)B=9!`<A(B?E(P>\"
M2,'A'D6)P$@)^8G/20G.32'62"'Z3`GR3(NT))`!``!)`<9-`?1-B<9,`>)-
MB<1)P>X;2<'D!4T)]$$!U$R)TDG!Z@)(P>(>18GD3`G22`G128G608G222'^
M3"'!3`GQ3(NT))@!``!)`<9-`?5-B>9,`>E-B>5)P>X;2<'E!4T)]4F)UD$!
MS4R)P4G!Z`)(P>$>18GM3`G!08G(20G.32'F3"'"3`GR3(NT)*`!``!)`<9,
M`?=-B>Y(`?I,B>])P>X;2,'G!4P)]P'73(GB2<'L`DC!XAZ)_TP)XD@)T4F)
MUD&)U$TAQDPAZ4P)\4R+M"2H`0``20'&30'R28G^3`'128GZ2<'N&TG!X@5-
M"?))B=9!`<I,B>E)P>T"2,'A'D6)TDP)Z4&)S4D)SDDA_DPAZDP)\DR+M"2P
M`0``20'&30'P38G63`'"38G02<'N&TG!X`5-"?!!`=!(B?I(P>\"2,'B'D6)
MP$@)^D@)T4F)UHG732'N3"'13`GQ3(NT)+@!``!)`<9-`?1-B<9,`>%-B<1)
MP>X;2<'D!4T)]$F)UD$!S$R)T4G!Z@)(P>$>18GD3`G120G.08G*32'&3"'2
M3`GR3(NT),`!``!)`<9-`?5-B>9,`>I-B>5)P>X;2<'E!4T)]4$!U4R)PDG!
MZ`)(P>(>18GM3`G"2`G128G008G732'03"'A3`G!3(N$),@!``!)`<!,`<=-
MB>A(`?E,B>])P>@;2,'G!4P)QT2-!#E,B>=)P>P"2(G12,'G'DP)YT&)_$@)
M^4PAZ4PAXD@)RDB+C"30`0``2`'!3`'138G"2`.$)-@!``!(`<I,B<%)P>H;
M2,'A!4P)T8G)2`'*3(GI2<'M`DC!X1Y!B=),">E("<])B<U!B<Y,(<=-(>5)
M"?U*C3PX3(G03(N\)/@!``!,`>]-B=5(P>`%2<'M&TP)Z(G`2`''3(G`2<'H
M`DC!X!Y!B?U)"<"XUL%BRDPQP3'12(N4).`!``!(`<),`>)-B>Q(`<I,B>E)
MP>P;2,'A!4P)X4V)U(G)2<'D'D@!RDG!Z@))`<=-">)-B<2)T46)P$TQU$0Q
MYTR+I"3H`0``20'$30'T28G.3`'G28G,2<'N&TG!Y`5-"?1-B>Y)P>T"2<'F
M'D6)Y$T)]4R+M"3P`0``3`'G08G\20'&30'P38G633'N1#'R38GF20'03(GB
M2<'N&TC!X@5,"?*)TDD!T$B)RDC!Z0)(P>(>18G&2`G*1(G138GJ23'23`'Y
M3(N\)``"``!$,==-B?)(`<],B?%(P>$%2<'J&TD!QTP)T8G)2`'/3(GA2<'L
M`DC!X1Y!B?I)"<Q$B>E)B=6)TDTQY4P!^4R+O"00`@``13'H38G520'(3(G1
M2<'M&TD!QTC!X05,">F)R4D!R$R)\4G![@)(P>$>18G%3`GQ3(NT)`@"``!)
M`<9,`?)-B>9),<Y$,?=-B>Y(`==,B>I)P>X;2,'B!4P)\HG22`'73(G22<'J
M`DC!XAY!B?Y)"=)$B>))B<R)R4P!^DTQU$R+O"0@`@``13'@38GT20'03(GR
M2<'L&TD!QTC!X@5,">*)TDD!T$R)ZDG![0)(P>(>18G$3`GJ3(NL)!@"``!)
M`<5,`>E-B=5),=5$,>]-B>5(`<],B>%)P>T;2,'A!4P)Z8G)2`'/3(GQ2<'N
M`DC!X1Y!B?U)"<Y$B=%)B=*)TDTQ\DP!^4R+O"0P`@``13'038GJ20'(3(GI
M2<'J&TC!X05,"=&)R4D!R$R)X4C!X1Y)P>P"18G"20''3`GA3(ND)"@"``!)
M`<1,`>)-B?1),<Q$,>=-B=1(`==,B=))P>P;2,'B!4P)XHG22`'73(GJ2<'M
M`DC!XAY!B?Q)"=5$B?))B<Z)R4TQ[DP!^DR+O"1``@``13'P38GF20'03(GB
M2<'N&TC!X@5,"?*)TDD!T$R)TDG!Z@)(P>(>18G&3`G23(N4)#@"``!)`<),
M`=%-B>I),=)$,==-B?)(`<],B?%(P>$%2<'J&TD!QTP)T8G)2`'/3(GA2<'L
M`DC!X1Y!B?I)"<Q$B>E)B=6)TDTQY4P!^4R+O"1@`@``13'H38G520'(3(G1
M2<'M&TC!X05,">F)R4D!R$R)\4G![@)(P>$>18G%3`GQ3(NT)$@"``!)`<9,
M`?)-B>9%B>1),<Y$,?=-B>Y(`==,B>I)P>X;2,'B!4P)\HG22`'73(G22<'J
M`DC!XAY!B?Y)"=)(BY0D4`(``$@!PDD!U$B)RHG)3#'220''1#'"38GP20'4
M3(GR2<'H&TC!X@5,"<*)TDD!U$R)ZDG![0)(P>(>18G@3`GJ3(NL)%@"``!)
M`<5,`>E-B=5),=5$,>]-B<5(`<],B<%)P>T;2,'A!4P)Z8G)2`'/3(GQ2<'N
M`DC!X1Y!B?U)"<Y$B=%)B=*)TDTQ\DP!^4R+O"1P`@``13'B38GL3`'138GJ
M2<'L&TG!X@5-">)-B<1%B=))P>0>3`'12<'H`DD!QTT)X$R+I"1H`@``08G*
M20'$2`.$)'@"``!,`>)-B?1,`<A-,<1$,>=-B=1(`==,B=))P>P;2,'B!4P)
MXDV)[$G![0))P>0>B=)-">5%B?1-B<9(`==-,>Z)^DT!_$6)P$0Q\4F)UDP!
MP$V)Z$P!X4F)U$G![AM)P>0%30GT1`'A38G42<'J`DG!Y!Z)R4T)XDTQT$0Q
MQTF)R$@!^$B)STC!YP5)P>@;`>E!`=I,"<=$`VX@2(E."`'X3(E6&$B)!DB)
MT$C!Z@)(P>`>3(EN($@)T$0!V$B)1A!(BX0DB`(``&1(*P0E*````'422('$
MF`(``%M=05Q!74%>05_#Z(;E__]F#Q]$``!!5T%6055!5%532(/L"$B%_P^$
ML0```$B+!1*/``!,BS!-A?8/A)X````/M@=)B?])B?6$P'0$/#UU544QY$F+
M'DB%VW0P36/D3(GU#Q]``$R)XDR)_DB)W^ABX___A<!U!T*`/",]=$=(BUT(
M2(/%"$B%VW7:2(/$"$B)V%M=05Q!74%>05_##Q^$``````!)B?Q!#[9$)`%)
M@\0!A,!T!#P]=>Y%*?SKE&8/'T0``$PI]4J-7",!2,']`T&);0#KM&8/'T0`
M`#';ZZH/'T``4TB)^TB![*````!D2(L$)2@```!(B80DF````#'`2(GFZ+KD
M__^%P'4VBU0D&('B`/```('Z`$```'0(@?H`H```=1Z^`@```$B)W^C_Y/__
MA<`/E,`/ML#K!P\?1```,<!(BY0DF````&1(*Q0E*````'4)2('$H````%O#
MZ"WD__]F9BX/'X0``````&:0055!5%532('LJ````&1(BP0E*````$B)A"28
M````,<!(A?]T"(`_`$B)^W4K2(N$))@```!D2"L$)2@````/A2,!``!(@<2H
M````6UU!7$%=PV8/'T0``.C3XO__2(G%2(7`=,A(B>_HH^3__TB%P`^$L@``
M`(!X$RY,C6`3=1!!@'PD`0!TW0\?A```````@'@3+@^$I@```$B)W^ANXO__
M3(GG28G%Z&/B__]!C7P%`DAC_^BVX?__38GA28G8O@$```!)B<5(B<<QP$C'
MPO____](C0U9+0``Z-#C__],B>](B>;H->+__TR)[X/X_W00BT0D&"4`\```
M/0!```!T7>B8X?__3(GOZ/#A__](B>_H^./__TB%P`^%5?___P\?@`````!(
MB>_H<./__TB)W^AXX?__Z?#^__\/'P!!@'PD`2X/A4[___]!@'PD`@`/A`W_
M___I/?___P\?`.B;_O__ZZ'HM.+__P\?0`#S#Q[Z4TB+'82,``!(C0U];0``
M2(TUL"P``$B+%7>,``!D2(L[Z$;C__]D2(L[3(T%,2X``%M(C16#'```13')
M3(G!2(TUG"P``.F1X?__D$%505154TB![``0``!(@PPD`$B#[!BZ_P\``&1(
MBP0E*````$B)A"0($```,<!)B>1(B?M(B?5(C3UM+```3(GFZ*KA__^%P'X2
MB<&#Z`%(8]"`/!0`=4B%P'4\2(L%W8L``$B)ZDB)WF1(BSCHCN#__TB+A"0(
M$```9$@K!"4H````=4Y(@<08$```6UU!7$%=PP\?1```B<%F#Q]$``!,8^F^
M+P```$R)YTR)ZNB=W___2(7`=*1(BP6!BP``3(GI3(GB2(G>9$B+..@/X?__
MZY_HB.'__P\?A```````05=!5D%505152(GU4TB)^TB#["AD2(L$)2@```!(
MB40D&#'`,<"`/CT/E,!(`<5(B>_H.>#__TB-="042(G?28G$,<#HM_O__TB%
MP`^$!@$``$B)QTF)Q>@3X/__3#G@#X/2````2&-,)!1,BS6^B@``3(T\S0``
M```/M@.$P`^$HP$``#P]#X2;`0``2(G8#[90`4B#P`&$TG0%@/H]=>](*=A(
MF$V++DJ-?"`"Z!W?__]-`?U)B44`2(7`=%))BP9(C4L!2HL4.`^V`X@"A,!T
M(CP]=0WK'`\?@`````"$P'01#[8!2(/"`4B#P0&(`CP]=>O&`CTQP&8/'T0`
M``^V3`4`B$P"`4B#P`&$R77O2(M$)!AD2"L$)2@````/A1<!``!(@\0H6UU!
M7$%=05Y!7\,/'T``,<!F#Q]$```/ME0%`$&(5`4`2(/``832=>[KO0\?0`!,
MBS71B0``38L&28,X``^$PP```$R)P$4Q[68/'T0``$B#P`A$B>I!@\4!2(,X
M`'7OC7(#2&/V2,'F`XL%'XH``(7`=6-(B?=,B40D",<%"8H```$```#H'-[_
M_TB)QTB%P`^$4?___TECS4B+="0(3(T\S0````!,B?KH2-___TF)!DB)QT&-
M10%$B6PD%$B82,<$QP````#IA/[__V8N#Q^$``````!,B<?H*.#__TF)!DB)
MQTB%P`^$^O[__TECS4R-/,T`````Z[H/'T``,<#I=_[__[X0````13'MZ5?_
M___H/]___V9F+@\?A```````#Q]``/,/'OI(BP4%B0``2(L5!HD``$B-#?=I
M``!(C34J*0``9$B+..G'W___#Q^``````/,/'OI54TB![``0``!(@PPD`$B!
M[``0``!(@PPD`$B#["AD2(L$)2@```!(B80D&"```#'`2(V<)!`0``!(B>7H
M:]W__[H!$```2(G?O@$```!!B<!,C0WZ*```,<!(C0WU*```Z";?__^Z`!``
M`$B)[DB)W^@6WO__A<!X4(UX`4B)PTAC_^C$W/__2(7`=#U(8]M(B>Y(B<=(
MB=KH/M___\8$&`!(B<%(BX0D&"```&1(*P0E*````'4-2('$*"```$B)R%M=
MP^@RWO__,<GKUV9F+@\?A```````#Q\`\P\>^ND7____#Q^``````/,/'OI!
M5T%6055!5%532('L`!```$B##"0`2('LN````&1(BP0E*````$B)A"2H$```
M,<!)B?Q(B?-(C3TW*```2(UT)`SH1?C__[XO````3(GG2(G%Z&7=__](A<!T
M0#'`3(GF2(T]%2@``.@?_/__3(G@2(N4)*@0``!D2"L4)2@````/A8(!``!(
M@<2X$```6UU!7$%=05Y!7\,/'P!(B=],C2WD)P``3(TUU2@``.@ZW?__3(GN
M2(G'Z&_=__](B<-(A<!TEX`[``^$Y````&8/'T0``$B%[7032(G>2(GOZ#C=
M__^%P`^$IP```$B)W^@(W/__2(U4`_])B<=(.=-R%^LE9@\?A```````Q@(`
M2(/J`4@YTW0%@#HO=.](B=_HU]O__TF)QTR)Y^C,V___28U$!P%(/?\/```/
MAQO___],C;PDH````$R)\4F)V#'`2(/L"+H`$```O@$```!,B?]!5$R-#2$G
M``#H+-W__TB-="0@3(G_Z(_;__]:687`=1"+1"0H)0#P```]`(```'1)3(GN
M,?_HC]S__TB)PTB%P`^$L_[__X`[``^%(O___TB%[70&@'T`+G070;\!````
M2(T=J"8``.E9____#Q]$``"`?0$`=+GKX;X!````3(G_Z,/<__^%P'6F3(G^
M2(T]AB8``.B0^O__3(G_Z.C;___I9_[__^C^V___9F8N#Q^$```````/'P#S
M#Q[Z4[XO````2(G[Z"[;__](C5`!2(7`2`]%VDB)WUOIJMO__V8N#Q^$````
M``#S#Q[Z55-(@>P`$```2(,,)`!(@^P89$B+!"4H````2(F$)`@0```QP$B%
M_P^$S@```(`_`$B)^P^$P@```.AMVO__2(U0`4B!^@`0```/A^0```!(B>5(
MB>^#^@AR#HG12(G>P>D#\TBE2(GS,<GVP@1T"8L+B0^Y!````/;"`G0.1`^W
M!`MF1(D$#TB#P0*#X@%T!P^V%`N(%`](C40%_T@YQ7(6ZQD/'X0``````,8`
M`$B#Z`%(.>AT!8`X+W3OOB\```!(B>_H0MK__TB%P'0M2#G%<EA(B>_HP-K_
M_TB+E"0($```9$@K%"4H````=4E(@<08$```6UW##Q\`2(N$)`@0``!D2"L$
M)2@```!U*4B!Q!@0``!(C3T%)0``6UWI>-K__P\?A```````Q@``ZZ,/'P`Q
MP.NDZ'_:__]F9BX/'X0```````\?0`#S#Q[Z05=!5D%505152(TMWB0``%-(
M@^P89$B+!"4H````2(E$)`@QP$B-7"0$9I`QP$B)WDB)[^BS]/__2(7`=#Y(
MBP77@P``2&-4)`1(BP!(C0302(M0"$B)$$B%TG3/#Q^``````$B+4!!(@\`(
M2(D02(72=?#KMF8/'T0``$B-+70D``!F#Q^$```````QP$B)WDB)[^A3]/__
M2(7`=#Y(BP5W@P``2&-4)`1(BP!(C0302(M0"$B)$$B%TG3/#Q^``````$B+
M4!!(@\`(2(D02(72=?#KMF8/'T0``$B-+1PD``!F#Q^$```````QP$B)WDB)
M[^CS\___2(7`=#Y(BP47@P``2&-4)`1(BP!(C0302(M0"$B)$$B%TG3/#Q^`
M`````$B+4!!(@\`(2(D02(72=?#KMF8/'T0``$B-+<4C``!F#Q^$```````Q
MP$B)WDB)[^B3\___2(7`=#Y(BP6W@@``2&-4)`1(BP!(C0302(M0"$B)$$B%
MTG3/#Q^``````$B+4!!(@\`(2(D02(72=?#KMF8/'T0``$B-+6PC``!F#Q^$
M```````QP$B)WDB)[^@S\___2(7`=#Y(BP57@@``2&-4)`1(BP!(C0302(M0
M"$B)$$B%TG3/#Q^``````$B+4!!(@\`(2(D02(72=?#KMF8/'T0``$R-)1PC
M``!F#Q^$```````QP$B)WDR)Y^C3\O__2(7`=#Y(BP7W@0``2&-4)`1(BP!(
MC0302(M0"$B)$$B%TG3/#Q^``````$B+4!!(@\`(2(D02(72=?#KMF8/'T0`
M`$R-)7$B``!F#Q^$```````QP$B)WDR)Y^AS\O__2(7`=#Y(BP67@0``2&-4
M)`1(BP!(C0302(M0"$B)$$B%TG3/#Q^``````$B+4!!(@\`(2(D02(72=?#K
MMF8/'T0``$R--6@B``!F#Q^$```````QP$B)WDR)]^@3\O__2(7`=#Y(BP4W
M@0``2&-4)`1(BP!(C0302(M0"$B)$$B%TG3/#Q^``````$B+4!!(@\`(2(D0
M2(72=?#KMF8/'T0``$R-+1(B``!F#Q^$```````QP$B)WDR)[^BS\?__2(7`
M=#Y(BP77@```2&-4)`1(BP!(C0302(M0"$B)$$B%TG3/#Q^``````$B+4!!(
M@\`(2(D02(72=?#KMF8/'T0``$R-/;PA``!F#Q^$```````QP$B)WDR)_^A3
M\?__2(7`=#Y(BP5W@```2&-4)`1(BP!(C0302(M0"$B)$$B%TG3/#Q^`````
M`$B+4!!(@\`(2(D02(72=?#KMF8/'T0``$R-/?H@``!F#Q^$```````QP$B)
MWDR)_^CS\/__2(7`=#Y(BP47@```2&-4)`1(BP!(C0302(M0"$B)$$B%TG3/
M#Q^``````$B+4!!(@\`(2(D02(72=?#KMF8/'T0``$B)WDB-/0,A``#HH?#_
M_TB%P'0-2(G&3(GO,<#HC_3__S'`2(G>2(T]\2```.A^\/__2(7`=!%(B<9(
MC3WO(```,<#H:/3__TB)WDB-/>D@```QP.A7\/__2(G&2(7`=#E,B><QP.A%
M]/__2(M$)`AD2"L$)2@```!U1$B#Q!A(B>](C373(```,<!;74%<05U!7D%?
MZ1;T__\QP$B)WDB-/:4@``#H!?#__TB%P'2[2(G&3(GW,<#H\_/__^NLZ&S5
M__]F9BX/'X0``````)#S#Q[Z2(/L&&1(BP0E*````$B)1"0(BP5D?P``@_C_
M=!](BU0D"&1(*Q0E*````'5&2(/$&,-F+@\?A```````2(UT)`1(C3W3'P``
M,<#HC>___TB)PC'`2(72=!(/M@(\,`^5PH3`#Y7`#[;`(=")!0M_``#KJNCD
MU/__#Q]``/,/'OI(@^P(Z!/5__^)Q^B,T___2(7`=`-(BP!(@\0(PV9F+@\?
MA```````#Q]``/,/'OI!54%43(TESQ\``%5(B?U,B>=32(/L&&1(BP0E*```
M`$B)1"0(,<!(C70D!.C[[O__2(7`=`B`.`!(B<-U+DB+1"0(9$@K!"4H````
M#X6P````2(GN2(/$&$R)YS'`6UU!7$%=Z</R__\/'P!(B>Y(B<?HI=/__TB%
MP'0@2(M$)`AD2"L$)2@```!U=DB#Q!A;74%<05W##Q]$``!(B>_H^-+__TB)
MWTF)Q>CMTO__28U\!0+H0]+__TB#[`A)B>B^`0```%-(Q\+_____2(G'28G%
M3(T-4!X``$B-#4$?```QP.A4U/__6%I(BT0D"&1(*P0E*````'4(3(GNZ5/_
M___HI=/__P\?1```\P\>^DB#[`B_@````.C>T?__9@]O!89>``!(QT`P````
M``\1`&8/;P6#7@``QT!X``````\10!!F#V\%@%X```\10"!(@\0(PP\?@```
M``#S#Q[Z05152(G]4TB#[!!D2(L$)2@```!(B40D"#'`Z&SW__^^+P```$B)
MQTB)P^ALTO__2(7`2(U0`4@/1=I(B=_HZ=+__TB%[4F)Q(L%'7T```^5PX/X
M_W1UA<`/E<`APX3;=2)(BT0D"&1(*P0E*`````^%I0```$B#Q!!;74%<PP\?
M1```@'T``'38N@0```!(C37T'0``3(GGZ.[0__^%P'7`2(M$)`AD2"L$)2@`
M``!U:4B#Q!!(B>];74%<Z6KN__]F+@\?A```````,<!(C70D!$B-/3$=``#H
M[>S__TB%P'0H#[80A-(/E<"`^C`/E<(AT"'##[;`B05M?```Z5K___\/'X0`
M`````,<%5GP```````#I1____^@LTO__9F8N#Q^$``````"0\P\>^D%72&/"
M059)B<9!54%428G\54B-;SA32(GS2(/L"$B+=RA(BU<PC0S&2#GQ2(E/*$B#
MT@!(P>@=2`'02(E',$AC1WB%P`^%Z0```$&#_C\/CB<!``!!@^Y`18GW0<'O
M!D6-;P%)P>4&20'=D/,/;P-,B>=(@\-`#Q%%`/,/;TO0#Q%-$/,/;U/@#Q%5
M(/,/;UOP#Q%=,.B1U?__3#GK=<Q!P><&12G^26/&2(/X"')<28M5`$B-30A(
M@^'X28E4)#A)BU0%^$B)5`7X2"G-2`'H22GM2(/@^$B#^`AR&$B#X/@QTDF+
M=!4`2(DT$4B#P@A(.<)R[D6)="1X2(/$"%M=05Q!74%>05_#9I"H!'5T2(7`
M=.%!#[95`$&(5"0XJ`)TTT$/MU0%_F:)5`7^Z\8/'T``0;]`````2(U\!0!(
MB=Y!*<=%.?=%#T_^36/O3(GJZ*71__]!BT0D>$0!^$&)1"1X@_A`=9),B>=%
M*?Y,`>OHM=3__^G/_O__28G=Z2/___]!BU4`08E4)#A!BU0%_(E4!?SI6___
M_Y#S#Q[Z059,C78X055!5%5(B?U33(MN*$B)\TR+9C!,B>A(P>@#@^`_C4@!
M2)C&1`8X@$ACP4P!\(/Y.`^.?P$``+Y`````*<YT#S'2B=&#P@'&!`@`.?)R
M\TB)W^@OU/__9@_OP`\10SA)QT8P`````$$/$48000\11B!,B>)!#[;%3(GO
M3(GN2,'J&$C!X`A,B>%(P>\028G03(GJ2,'N&`^VUD`/MO]`#[;V2,'I$$@)
MT$R)X@^VR4C!X`A("?@/MOY!#[;02,'@"$@)\$$/MO1(P>`(2`GP2,'@"$@)
M^$B)WTC!X`A("<A(P>`(2`G02(E#<.B6T___2(L#2(G?2,'H&(A%`$B+`TC!
MZ!"(10%(BP.(90)(BP.(10-(BT,(2,'H&(A%!$B+0PA(P>@0B$4%2(M#"(AE
M!DB+0PB(10=(BT,02,'H&(A%"$B+0Q!(P>@0B$4)2(M#$(AE"DB+0Q"(10M(
MBT,82,'H&(A%#$B+0QA(P>@0B$4-2(M#&(AE#DB+0QB(10](BT,@2,'H&(A%
M$$B+0R!(P>@0B$412(M#((AE$DB+0R"(11-;74%<05U!7NFFS?__9@\?1```
MNC@````Q_RG*@_H(<D*)T4C'``````!(QT0(^`````!(C4@(2(/A^$@IR`'"
M@^+X@_H(#X*"_O__@^+X,<")QH/`"$B)/#$YT'+SZ6O^___VP@1U(X72#X1>
M_O__Q@``]L("#X12_O__,<EFB4P0_NE&_O__#Q\`QP``````QT00_`````#I
M,/[__P\?1```\P\>^D%7059!54%455-,C9PD`(#__TB![``0``!(@PPD`$PY
MW'7O2('L6`$``$B-#4L9``!(C14*&0``9D@/;L%(C0WA&```9$B+!"4H````
M2(F$)$B!``!(C04V&```2(U<)!Q)B?Y(C3TI&```2,=$)%``````2(G>2,>$
M)(@`````````2,=$)#``````9D@/;LA(C07I&```9@]LP69(#V[02(T%X1@`
M``\I1"1`9D@/;L%F2`]NV$B-#<\8``!F#VS"2(T%R1@```\11"1H9D@/;L)F
M2`]NX#'`9@]LPP\11"1X9D@/;L%F#VS$#RE$)"#HMN?__TB%P'0,@#@`2(G%
M#X5M!```Z&#-__^)Q^C9R___2(7`#X3@`P``3(LH387M#X34`P``3(GOZ.S+
M__](C7P``>A"R___10^V10!)B<=)B<1%A,!T.4B-+4H8```/'P!%#[;`3(G_
M2(GIO@$```!(Q\+_____,<!)@\4!28/'`NA#S?__10^V10!%A,!UT4R-;"1@
M2(T]G1<``.L0#Q\`28M]"$F#Q0A(A?]T.TB)WC'`Z`'G__](B<5(A<!TX8`X
M`'3<2(G'Z+SG__^%P'302(GOZ$#,__](B<5(A<!U0`\?A```````3(UL)$!)
MBVT`2(7M="J`?0``#X3X`@``2(GOZ(#G__^%P`^%"`$``$F+;0A)@\4(2(7M
M==D/'P!(B>_H`,O__TR)YTF)Q>CURO__08V$!00$``!,8_A,B?_H0LK__T%4
M28GHO@$```!)B<5(C04<%P``3(T-5Q8``$C'PO____]02(T-/!<``$R)[S'`
MZ$[,__],B>^^P`$``.BQS/__7T%8@_C_=1+H=,O__T2+"$&#^1$/A;$"``!(
MC80DD````$R)[TB)QDB)!"3HL,O__XG%A<!T>DB+!6MU``!)BPY-B>A(C16&
M%P``O@$```!(BS@QP.A7R?__13'D2(N$)$B!``!D2"L$)2@````/A4`%``!(
M@<18@0``3(G@6UU!7$%=05Y!7\,/'X0``````$B)[TF#Q0CH],K__TB)Q4B%
MP`^$O?[__^GK_O__#Q\`BX0DJ````"4`\```/0!````/A6____]$BZ0DK```
M`.@<R___03G$#X59____BX0DJ````"7_`0``/<`!```/A4+___],B?_H!,G_
M_TB)WDB-/>,5``!)B<0QP.@@Y?__2(7`#X0_`@``28L^2(G&Z'SL__])B<=(
MA<`/A"@"``!,B?_H:,G__TB)PH/X`WY`2)A(C37D%0``2(E4)`A)C7P'_.AH
MRO__A<!U)$B+5"0(@_H$#X2E`P``C4+[2)A!@#P'+P^$E0,``&8/'T0``(L%
M2G0``(/X_P^$20,``(7`#X39`0``2(TU/A4``$B-/<H4```QP.B$Z/__2(T=
MLQ4``$R--9H5``#HH<C__U-(Q\+_____38GH4$R-#5X4``"^`0```$R)YTB-
M#645```QP.A8RO__6%KK1`\?0`#HB\G__X,X$75(Z&'(__^#Q0%(@^P(38GH
M4TR-#1\4``!,B?&^`0```%5(Q\+_____3(GG4#'`Z!3*__](@\0@OL`!``!,
MB>?H<\K__X/X_W2N3(GOZ$;(__],B>9(C3W$$P``,<#HU>?__TR)Y^B=]/__
MZ?3]__\/'X0``````#'MZ2']__]F#Q^$``````!(C6PD(.L-9@\?A```````
M2(/%"$B+?0!(A?\/A(\````QP$B)WNB%X___2(7`=."`.`!TVTB)Q^C3R/__
M28G%2(7`=,OIXOO__TB+!==R``!)BPY-B>A(C16R%```O@$```!(BS@QP.C#
MQO__Z6?]__]F#Q]$``!(B<?H`/3__TB+A"1(@0``9$@K!"4H````#X6<`@``
M2('$6($``$B)[UM=05Q!74%>05_I8,C__[\-````3(TMO1,``.B_QO__0;A3
M````28G'28G$Z7S[__]F#Q]$``!-BS[IT/W__\<%9G(```````!F#Q]$```Q
M]DR)_S'`Z)3'__^)PX7`#X01_O__N@(```!(Q\;N____B<?HA\C__TR-M"1`
M`0``N@8```")WTR)]N@PQO__@+PD0`$```!U#H"\)$$!``!##X2"`0``,=(Q
M]HG?Z$W(__^_@````.@CQO__9@]O!<M2``!(QT`P`````$B)Q0\1`&8/;P7%
M4@``QT!X``````\10!!F#V\%PE(```\10"#K#P\?0`!,B?9(B>_H;?7__[H`
M@```3(GVB=_HKL7__XG"A<!_X(G?3(V\)"`!``!(C9PDN````.@QQ?__2(GN
M3(G_2(TMPQ(``.C/]O__3(LT)`\?`$4/M@=,B?=(B>F^`0```$C'PO____\Q
MP$F#Q@))@\<!Z+/'__],.?-UUDB-!<T2``#&A"2X`````%#_="0(2(T-BA(`
M`$V)Z$R)YS'`O@$```!,C0UO$0``2,?"_____^ASQ___65[I;OW__P\?0``Q
MP$B)WDB-/8L1``#H1^'__TB%P`^$;O[__P^V`(3`#Y7"/#`/E<`/ML`AT(D%
MQG```.F`_/__38MV"$V%]@^$9/S__TR)]^A\Q?__2(/X`P^&4OS__TF-?`;\
M2(TU^!$``.B!QO__A<!-#T3^Z3;\__^`O"1"`0``00^%</[__X"\)$,!``!#
M#X5B_O__@+PD1`$``$@/A53^__^`O"1%`0``10^%1O[__[H"````2,?&QO__
M_XG?Z(O&__^Z*0```$R)]HG?Z#S$__](C06[$0``4$%6Z?/^___H^,7__P\?
MA```````\P\>^D%42(T]AA```%532(/L$$B+';9O``!D2(L$)2@```!(B40D
M"#'`3(UD)`1,B>9D2(LK#[:%L````(B%L0```#'`Z";@__](A<!T"8`X,0^$
M:`$``#'`Z"'K__]D2(LK2(GON0,```"Z`0```$B--2X1``#HY,/__TB)Q4B%
MP'0H2(M`$&1(BSM(C144$0``2(LPZ/7#__](BT402(LP]D8.0`^%1`$``&1(
MBSNY`P```+H!````2(TUZQ```.B:P___2(G%2(7`="U,B>9(C3V)#P``,<#H
MD=___TB)PDB%P`^$Y0```$B+11!D2(L[2(LPZ)7#__]D2(L[N@$```!(C36C
M$```Z*#"__]D2(L[2(T5J!```$B)QNAMP___9$B+`TR)YDB-/2</``#&@+$`
M````,<#H,=___TB)!?)N``!(B<-(A<!T0K[``0``2(G?Z)7%__^-4`&#^@%V
M"8/X$0^%D@```$B+1"0(9$@K!"4H````#X6;````2(/$$%M=05S##Q^`````
M`$B+/:EN``#H)/;__TB)!95N``!(B<-(A<!UHTB-/;80```QP.B'Q/__#Q^`
M`````(!X`0`/A)G^___IB?[__Y!(BP5I;@``2(LP2(M%$$B+..BJX?__Z1#_
M__\/'T0``&1(BSOHY\/__^FN_O__B<%(BP4Y;@``2(G:2(T]?Q```$B+,#'`
MZ"7$___HT,/___,/'OI(BPW=;0``Z>#!___S#Q[Z2(/L"$B#Q`C#````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````$``@`E<R\E<P!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`
M26YT97)N86QS.CI005(Z.D)/3U0`+W!R;V,O<V5L9B]E>&4`+W!R;V,O)6DO
M)7,`+@!005)?5$5-4`!005)?4%)/1TY!344`.@`O`%!%4DPU3$E"`%!%4DQ,
M24(`4$523#5/4%0`4$523$E/`%!!4E])3DE424%,25I%1`!005)?4U!!5TY%
M1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?1TQ/0D%,7T1%
M0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(`4$%27T=,3T)!3%]4
M14U0`%!!4E]'3$]"04Q?0TQ%04X`,0!,1%],24)205)97U!!5$@`<&%R+0`M
M90`M+0!365-414T`+W1M<`!414U01$E2`%1-4`!54T52`%5315).04U%`"4P
M,G@`)7,E<R5S)7,`<&%R;``N<&%R`"5S)7-C86-H92TE<R5S`"5S)7-T96UP
M+25U)7,`)7,E<W1E;7`M)74M)74E<P`8`'!E<FP`,`!005(Z.E!A8VME<CHZ
M5D524TE/3@`Q+C`U-@``````````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@
M<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@```````"5S.B!P
M<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO
M=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N*0H```````!5;F%B;&4@
M=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0``````````)7,Z(&-R96%T:6]N
M(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R
M;F\])6DI"@``````````979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D
M,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S
M:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)%!!4E]-04=)0RP@)$9)3$5?
M;V9F<V5T7W-I>F4L("1#04-(15]M87)K97(L("1C86-H95]N86UE7W-I>F4I
M.PI"14=)3B!["B1005)?34%'24,@/2`B7&Y005(N<&U<;B(["B1&24Q%7V]F
M9G-E=%]S:7IE(#T@-#L@("`C('!A8VLH(DXB*0HD8V%C:&5?;6%R:V5R(#T@
M(EPP0T%#2$4B.PHD8V%C:&5?;F%M95]S:7IE(#T@-#`["GT*<W5B(&9I;F1?
M<&%R7VUA9VEC"GL*;7D@*"1F:"D@/2!`7SL*;7D@)&-H=6YK7W-I>F4@/2`V
M-"`J(#$P,C0["FUY("1B=68["FUY("1S:7IE(#T@+7,@)&9H.PIM>2`D<&]S
M(#T@)'-I>F4@+2`D<VEZ92`E("1C:'5N:U]S:7IE.R`@("`@(",@3D]413H@
M)'!O<R!I<R!A(&UU;'1I<&QE(&]F("1C:'5N:U]S:7IE"G=H:6QE("@D<&]S
M(#X](#`I('L*<V5E:R`D9F@L("1P;W,L(#`["G)E860@)&9H+"`D8G5F+"`D
M8VAU;FM?<VEZ92`K(&QE;F=T:"@D4$%27TU!1TE#*3L*:68@*"AM>2`D:2`]
M(')I;F1E>"@D8G5F+"`D4$%27TU!1TE#*2D@/CT@,"D@>PHD<&]S("L]("1I
M.PIR971U<FX@)'!O<SL*?0HD<&]S("T]("1C:'5N:U]S:7IE.PI]"G)E='5R
M;B`M,3L*?0IM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE+"`E
M36]D=6QE0V%C:&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E
M<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q
M=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z
M.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<5M296UO=FEN9R!F:6QE<R!I
M;B`B)'!A<E]T96UP(ETI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@
M*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@
M)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS
M,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]/B`G
M=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O
M<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIM>2`D
M9FEL96YA;64@/2`D=&UP+3YF:6QE;F%M93L*<')I;G0@)'1M<"`\/"(N+BXB
M.PIX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?
M=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I
M"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<D9FEL96YA;64G
M"BXN+@IC;&]S92`D=&UP.PIC:&UO9"`P-S`P+"`D9FEL96YA;64["FUY("1C
M;60@/2`B)&9I;&5N86UE(#XO9&5V+VYU;&P@,CXF,2`F(CL*<WES=&5M*"1C
M;60I.PIO=71S*'%Q6U-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E
M<F9O<FT@8VQE86YU<#H@)&9I;&5N86UE72D["GT*?2!]"D)%1TE.('L*26YT
M97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!
M4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T(#T@
M(21%3E9[4$%27T1%0E5'?3L*;7D@)7-Y<R`]("@*<&%T:%]S97`@("`@/3X@
M*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^
M("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G
M)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<
M)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*;W5T<RAQ<5M<)'!R;V=N
M86UE(#T@(B1P<F]G;F%M92)=*3L*7W-E=%]P87)?=&5M<"@I.PIO=71S*'%Q
M6UPD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2)=*3L*;7D@*"1S
M=&%R=%]P;W,L("1D871A7W!O<RD["DU!1TE#.B!["FQO8V%L("1324=[7U]7
M05).7U]](#T@<W5B('M].PIU;FQE<W,@*&]P96X@7T9(+"`G/#IR87<G+"`D
M<')O9VYA;64I('L*;W5T<RAQ<5M#86XG="!R96%D(&9R;VT@9FEL92`B)'!R
M;V=N86UE(ETI.R`@(R!D;VXG="!U<V4@)"$@:&5R92!A<R!I="!R97%U:7)E
M<R!%<G)N;RYP;0IL87-T($U!1TE#.PI]"FUY("1M86=I8U]P;W,@/2!F:6YD
M7W!A<E]M86=I8R@J7T9(*3L*:68@*"1M86=I8U]P;W,@/"`P*2!["F]U=',H
M<7%;0V%N)W0@9FEN9"!M86=I8R!S=')I;F<@(B1005)?34%'24,B(&EN(&9I
M;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0SL*?0IO=71S*")&;W5N9"!0
M05(@;6%G:6,@870@<&]S:71I;VX@)&UA9VEC7W!O<R(I.PIS965K(%]&2"P@
M)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE+"`P.PIR96%D(%]&2"P@
M)&)U9BP@)$9)3$5?;V9F<V5T7W-I>F4["FUY("1O9F9S970@/2!U;G!A8VLH
M(DXB+"`D8G5F*3L*;W5T<R@B3V9F<V5T(&9R;VT@<W1A<G0@;V8@1DE,17,@
M:7,@)&]F9G-E="(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F
M9G-E=%]S:7IE("T@)&]F9G-E="P@,#L*)&1A=&%?<&]S(#T@=&5L;"!?1D@[
M"FUY("5R97%U:7)E7VQI<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@("`@
M("`@("`@("`@("`@("`@("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B"G=H
M:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A
M9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@
M/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B+BXN
M72D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO
M?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B
M=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L
M(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E
M9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I
M*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D8W)C)&5X="(L("1B=68L
M(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D
M9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]
M("1F=6QL;F%M93L*?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB
M+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@*2!["FUY("1F:6QE;F%M
M92`](%]S879E7V%S*"(D8F%S96YA;64D97AT(BP@)&)U9BP@,#<U-2D["F]U
M=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PI]"F5L<V4@>PHD36]D=6QE0V%C
M:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN
M86UE(#T^("1F=6QL;F%M92P*?3L*)')E<75I<F5?;&ES='LD9G5L;&YA;65]
M*RL["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@
M>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO
M9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN9F\@/2`D36]D=6QE0V%C:&5[)&UO
M9'5L97T["G)E='5R;B!U;FQE<W,@)&EN9F\["F1E;&5T92`D<F5Q=6ER95]L
M:7-T>R1M;V1U;&5].PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&EN9F\O
M)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/
M.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL
M92!O<B!D:64@(D-A;B=T(&-R96%T92!T96UP(&9I;&4Z("0A(CL*)&9H+3YB
M:6YM;V1E*"D["B1F:"T^<')I;G0H)&EN9F\M/GMB=69]*3L*)&9H+3YS965K
M*#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?
M<V%V95]A<R@B)&EN9F\M/GMC<F-]+G!M(BP@)&EN9F\M/GMB=69]*3L*)&EN
M9F\M/GMF:6QE?2`]("1F:6QE;F%M93L*;W!E;B!M>2`D9F@L("<\.G)A=R<L
M("1F:6QE;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&5N86UE(CH@
M)"%=.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z
M(&-A;B=T(&9I;F0@;6]D=6QE("1M;V1U;&4A(CL*?2P@0$E.0RD["G)E<75I
M<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P
M.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ
M.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@
M*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI
M('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"
M4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U
M:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D
M9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@
M)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]"G5N;&5S<R`H)&)U9B!E<2`B
M4$M<,#`S7#`P-"(I('L*;W5T<RAQ<5M.;R!Z:7`@9F]U;F0@869T97(@1DE,
M12!S96-T:6]N(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0R`[
M"GT*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@("`@("`@("`@("`@
M("`C('-T87)T(&]F('II<`I]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B
M=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?
M05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I
M='D@<')O8FQE;2D*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G
M+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W
M*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A
M;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%2
M1U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*
M)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C
M(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@
M*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N
M*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN
M8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]
M"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]
M"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E
M<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G
M*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q
M=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@
M(CX^(BP@)#(@;W(@9&EE('%Q6T-A;B=T(&]P96X@;&]G(&9I;&4@(B0R(CH@
M)"%=.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*
M?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@
M>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER
M92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!
M4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET
M.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T
M*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`[
M"G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6
M*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@
M)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@9FEN9"!P87(@9FEL92`B
M)'!A<B(Z("0A73L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R
M8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D
M9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92!Q
M<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<&%R(ET["GT*;7D@)6UE
M=&%?<&%R(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC
M;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M
M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI
M.B`H+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@
M)'!H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!R96%D('!A<B!F
M:6QE("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@-#L*
M9&EE('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@9FEL95T@=6YL97-S("1B=68@
M97$@(E!+7#`P,UPP,#0B.PIC;&]S92`D<&@["GT*0W)E871E4&%T:"@D;W5T
M*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/
M7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/
M7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE('%Q6T-A;B=T(&-R96%T92!F:6QE
M("(D;W5T(CH@)"%=.PHD9F@M/F)I;FUO9&4H*3L*<V5E:R!?1D@L(#`L(#`[
M"FUY("1L;V%D97(["FEF("AD969I;F5D("1D871A7W!O<RD@>PIR96%D(%]&
M2"P@)&QO861E<BP@)&1A=&%?<&]S.PI](&5L<V4@>PIL;V-A;"`D+R`]('5N
M9&5F.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!4E]615)"051)
M37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@
M4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M
M/F%P<&QY*%PD;&]A9&5R+"`D,"D["GT*:68@*"1M971A7W!A<GMC;&5A;GTI
M('L*;7D@)'!A<E]C;&5A;B`]("(],2(["FUY("1P87-S7W!A<E]C;&5A;B`]
M('5C(")?7W!A<W-?<&%R7V-L96%N7U\B.PHD;&]A9&5R(#U^('-[*#\\/21[
M<&%S<U]P87)?8VQE86Y]*2@@*RE]"GLD<&%R7V-L96%N("X@*"(@(B!X("AL
M96YG=&@H)#$I("T@;&5N9W1H*"1P87)?8VQE86XI*2E]96<["GT*)&9H+3YP
M<FEN="@D;&]A9&5R*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!L;V%D97(@
M=&\@(B1O=70B.B`D(5T["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(
M96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN
M8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)3
M1%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@
M)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG
M.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D
M?'P@9F]R96%C:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@
M0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*
M;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@("`@
M("`@(R!86%@@;&EB7V5X="!V<R!D;&5X="`_"FUY("5W<FET=&5N.PIF;W)E
M86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D
M;F%M92D["FEF("AD969I;F5D*&UY("1F8R`]("1005(Z.DAE879Y.CI&=6QL
M0V%C:&5[)&ME>7TI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("1F8RD[
M"GT*96QS92!["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]
M?B!M?%Y<421D:7)<12\H+BHI)'QI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K
M97DL("0Q*3L*;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK
M+R@N*BDD?"D@>PII9B`H;7D@)')E9B`]("1-;V1U;&5#86-H97LD,7TI('L*
M*"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B
M)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D[
M"FQA<W0["GT*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X
M="!I9B`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A
M;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H
M<7%;4&%C:VEN9R!&24Q%("(E<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL92T^
M>VYA;65](#H@)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I
M*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D
M+R`]('5N9&5F.PIO<&5N(&UY("1T:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE
M('%Q6T-A;B=T(')E860@(B1F:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD=&@^
M.PIC;&]S92`D=&@["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C
M;VYT96YT+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"
M051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&
M:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F
M:6QE+"`D;F%M92D["GT*)&9H+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L
M96YG=&@H)&YA;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E
M.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE*2P*<&%C:R@G
M3B<L(&QE;F=T:"@D8V]N=&5N="DI+`HD8V]N=&5N="D*;W(@9&EE('%Q6T5R
M<F]R('=R:71I;F<@96UB961D960@1DE,12!T;R`B)&]U="(Z("0A73L*;W5T
M<RAQ<5M7<FET=&5N(&%S("(D;F%M92)=*3L*?0I]"FEF("@D>FEP*2!["B1Z
M:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@/3T@07)C:&EV93HZ6FEP.CI!
M6E]/2PIO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!Z:7`@<&%R="!O9B`B)&]U
M=")=.PI]"B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`D
M8V%C:&5?;F%M95]S:7IE.PII9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I
M;64@/2`H<W1A="@D;W5T*2E;.5TI('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!
M+3YN97<H,2D["F]P96X@;7D@)'1H+"`B/#IR87<B+"`D;W5T.PHD8W1X+3YA
M9&1F:6QE*"1T:"D["F-L;W-E("1T:#L*)&-A8VAE7VYA;64@/2`D8W1X+3YH
M97AD:6=E<W0["GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@D8V%C:&5?;F%M
M95]S:7IE("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A8VAE7VYA;64@+CT@
M)&-A8VAE7VUA<FME<CL*;7D@)&]F9G-E="`]("1F:"T^=&5L;"`K(&QE;F=T
M:"@D8V%C:&5?;F%M92D@+2!L96YG=&@H)&QO861E<BD["B1F:"T^<')I;G0H
M)&-A8VAE7VYA;64L"G!A8VLH)TXG+"`D;V9F<V5T*2P*)%!!4E]-04=)0RD*
M)B8@)&9H+3YC;&]S90IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!T<F%I;&5R
M(&]F("(D;W5T(CH@)"%=.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*
M;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE
M*"D["G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R
M*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII
M<#L*?0IM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.R`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(R!!<F-H:79E.CI::7`@;W!E<F%T97,@;VX@86X@24\Z
M.DAA;F1L90HD9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@
M<7%;9F1O<&5N*"D@9F%I;&5D.B`D(5T["D%R8VAI=F4Z.EII<#HZ<V5T0VAU
M;FM3:7IE*"US(%]&2"D["FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*
M*"1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@
M07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN
M9R!Z:7`@87)C:&EV92`B)'!R;V=N86UE(ET["D%R8VAI=F4Z.EII<#HZ<V5T
M0VAU;FM3:7IE*#8T("H@,3`R-"D["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z
M:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PIO=71S*")%
M>'1R86-T:6YG('II<"XN+B(I.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0
M?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M
M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R
M+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL
M94YA;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL
M:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH/SHD0V]N9FEG
M.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A
M8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T
M9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D
M9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ
M92@I*2!["F]U=',H<7%;4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@
M:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B72D["GT@96QS92![
M"F]U=',H<7%;17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?
M;F%M92(N+BY=*3L**"1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S
M=%]N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%
M<G)O<B!E>'1R86-T:6YG('II<"!M96UB97(@=&\@(B1D97-T7VYA;64B73L*
M8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]
M"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE
M(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=
M(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M
M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6
M>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6
M*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER
M92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I
M(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI
M.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T
M:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R
M"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E
M($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0[
M"G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P
M.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E
M($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&
M8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,[
M"G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/
M.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z
M.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ
M4TA!.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E
M(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E
M<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R
M:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@
M5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@
M>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q
M=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER
M92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E
M<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN
M960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI
M+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A
M=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-
M4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN
M97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@
M)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED
M*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE
M9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ
M3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA
M;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!
M345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*;7D@)'-T;7!D:7(@
M/2`B)'!A=&@D<WES>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N
M86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FUY("1C86-H95]D:7(["FEF
M("@D14Y6>U!!4E]#3$5!3GTI('L*)&-A8VAE7V1I<B`](")T96UP+20D(CL*
M?0IE;'-E('L*;W!E;B!M>2`D9F@L("(\.G)A=R(L("1P<F]G;F%M92!O<B!D
M:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE(CH@)"%=.PII9B`H*&UY("1M
M86=I8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@D9F@I*2`^/2`P*2!["G-E96L@
M)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H
M)&-A8VAE7VUA<FME<BDL(#`["FUY("1B=68["G)E860@)&9H+"`D8G5F+"!L
M96YG=&@H)&-A8VAE7VUA<FME<BD["FEF("@D8G5F(&5Q("1C86-H95]M87)K
M97(I('L*<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ
M90HM(&QE;F=T:"@D8V%C:&5?;6%R:V5R*0HM("1C86-H95]N86UE7W-I>F4L
M(#`["G)E860@)&9H+"`D8G5F+"`D8V%C:&5?;F%M95]S:7IE.PHD8G5F(#U^
M(',O7#`O+V<["B1C86-H95]D:7(@/2`B8V%C:&4M)&)U9B(["GT*?0IC;&]S
M92`D9F@["GT*:68@*"$D8V%C:&5?9&ER*2!["B1C86-H95]D:7(@/2`B=&5M
M<"TD)"(["B1%3E9[4$%27T-,14%.?2`](#$["GT*)'-T;7!D:7(@+CT@(B1S
M>7-[7V1E;&EM?21C86-H95]D:7(B.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*
M)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;&%S=#L*?0HD<&%R7W1E;7`@
M/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@
M+R@N*RDO.PI]"G-U8B!?<V%V95]A<R!["FUY("@D;F%M92P@)&-O;G1E;G1S
M+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M
M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D
M9G5L;&YA;64N)"0B.PIM>2`D9F@["BAO<&5N("1F:"P@)SXZ<F%W)RP@)'1E
M;7!N86UE*0HF)B`H<')I;G0@)&9H("1C;VYT96YT<RD*)B8@*&-L;W-E("1F
M:"D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@(B1T96UP;F%M92(Z("0A73L*
M8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA
M;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I
M.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@>PII
M9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!2
M3T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N
M86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O
M9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U
M8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM
M?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D
M<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D
M9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@
M*"US("(D<')O9VYA;64D<WES>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)'-Y
M<WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O
M7%$D<WES>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X
M:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0
M?3L*)&1I<B`]?B!S+UQ1)'-Y<WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE
M(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](BDL(&QA
M<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE
M?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B
M*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B.PI]
M"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.
M5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D<WES>U]D
M96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1S>7-[7V1E;&EM?21P<F]G
M;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#
M=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I
M;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M
M92`]?B!S+UXH/SU<+EPN/UQ1)'-Y<WM?9&5L:6U]7$4I+R1P=V0D<WES>U]D
M96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B
M(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK
M(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:
M141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@
M0T%#2$4@4%)/1TY!344@*2`I('L*9&5L971E("1%3E9[(E!!4E\D7R)].PI]
M"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLB
M4$%27R1?(GT@/2`D14Y6>R)005)?1TQ/0D%,7R1?(GT@:68@97AI<W1S("1%
M3E9[(E!!4E]'3$]"04Q?)%\B?3L*?0II9B`H)$5.5GM005)?5$5-4'TI('L*
M9&5L971E("1%3E9[4$%27T-,14%.?3L*?0I]"G-U8B!O=71S('L*<F5T=7)N
M(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB
M.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR
M97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D
M0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP
M('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L
M:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T
M($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S
M*3L*9&EE('%Q6W!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R
M;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU;FQE<W,@
M+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF
M("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*
M?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF
M("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z
M.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH`````<&5R;'AS
M:2YC`````````/____\`````_____P`````!(T5G`````(FKS>\`````_MRZ
MF`````!V5#(0`````/#ATL,````````````````!&P,[]````!T`````;___
M*`$``'!R__]0`0``@'+__V@!``#@=?__=`4``/!W__\0`0``X'C__X`!``!0
MC___T`$``""0__\<`@``L)#__T`"```@DO__?`(``'"2__^8`@``4)/__]@"
M``"@E?__)`,``-"5__\X`P``L);__VP#``#`EO__@`,``."8___D`P``$)G_
M_P`$``!@FO__/`0``'"?__^(!```\)___Z0$```@H/__O`0``#"A__\8!0``
M@*'__S`%``"PHO__H`4``%"D___L!0``H*;__RP&``#@KO__!`<```"Q__\X
M!P```````!0``````````7I2``%X$`$;#`<(D`$``!0````<````V';__R8`
M````1`<0`````"0````T````T&W__W`#````#A!&#AA*#PMW"(``/QHZ*C,D
M(@`````4````7````!AQ__\0```````````````4````=````!!Q__]@`P``
M``````````!,````C````%AW__]J%@```$(.$(\"20X8C@-"#B"-!$(.*(P%
M00XPA@9!#CB#!T<.T`4#0A8*#CA!#C!!#BA"#B!"#AA"#A!"#@A!"P```$@`
M``#<````>(W__\P`````0@X0CP)"#AB.`T(.((T$0@XHC`5!#C"&!D$..(,'
M1`Y``FP*#CA$#C!!#BA"#B!"#AA"#A!"#@A)"P`@````*`$``/R-__^#````
M`$$.$(,"2@ZP`0)Q"@X000X(00LX````3`$``&B.__]L`0```$(.$(T"0@X8
MC`-!#B"&!$$.*(,%1P[0`7X*#BA!#B!!#AA"#A!"#@A'"P`8````B`$``)R/
M__]/`````$4.$(,"<0X(````/````*0!``#0C___V`````!"#A"-`D(.&(P#
M00X@A@1!#BB#!4<.J"!)#L`@`G8*#BA!#B!!#AA"#A!"#@A&"T@```#D`0``
M<)#__T$"````0@X0CP)"#AB.`T(.((T$0@XHC`5!#C"&!D0..(,'1PY@`Q4!
M"@XX00XP00XH0@X@0@X80@X00@X(10L0````,`(``'22__\I`````````#``
M``!$`@``D)+__](`````10X0A@)!#AB#`T<.F"!,#IA`20[`0`*A"@X81`X0
M00X(00L0````>`(``#R3__\)`````````&````",`@``.)/__Q("````1@X0
MCP)"#AB.`T(.((T$0@XHC`5!#C"&!D$..(,'1PZX($P.\"$"<0H..$$.,$$.
M*$(.($(.&$(.$$(."$0+`KD.^"%/#H`B6@[X(4$.\"$````8````\`(``/24
M__\F`````$4.$(,"7`X(````.`````P#```(E?__00$```!%#A"&`D$.&(,#
M1PZ8($D.L"`"Y`H.&$$.$$$."$0+6@H.&$@.$$$."$T+2````$@#```<EO__
M!`4```!&#A"/`D(.&(X#0@X@C01"#BB,!4$.,(8&2`XX@P=$#E`#I@0*#CA-
M#C!!#BA"#B!"#AA"#A!"#@A%"Q@```"4`P``X)K__WP`````2`X@;0H."$L+
M```4````L`,``$2;__\A`````$@.$%@."`!8````R`,``%R;__\+`0```$8.
M$(T"0@X8C`-(#B"&!$<.*(,%1`Y``D(*#BA&#B!!#AA"#A!"#@A("V0*#BA!
M#B!!#AA"#A!"#@A&"V$.2$D.4&,.2$$.0````!0````D!```$)S__TD`````
M2`X0`D`."$`````\!```2)S__R0!````1@X0C`)!#AB&`T0.((,$1`XP`F\*
M#B!!#AA!#A!"#@A&"W(*#B!$#AA!#A!"#@A/"P``*````(`$``!D</__$`(`
M``!%#A"&`D$.&(,#1`Y0`VL!"@X80PX000X(00M(````K`0```B=__^?`0``
M`$8.$(\"10X8C@-%#B"-!$(.*(P%1`XPA@9%#CB#!T<.0`+A"@XX00XP00XH
M0@X@0@X80@X00@X(0PL`/````/@$``!<GO__2P(```!&#A".`D8.&(T#0@X@
MC`1!#BB&!40.,(,&`YL!"@XH00X@0@X80@X00@X(2PL``-0````X!0``;*#_
M_S@(````1@X0CP)"#AB.`T(.((T$0@XHC`5!#C"&!D$..(,'2`P+N(`"40T'
M1PZ0@P(#$@(.F(,"80Z@@P)?#IB#`D(.D(,"`G@*#CA$#C!!#BA"#B!"#AA"
M#A!"#@A)"P,P`0Z8@P)+#J"#`EX.F(,"00Z0@P)<#IB#`D0.H(,"4`ZH@P)+
M#K"#`DL.D(,"`NX*#CA$#C!!#BA"#B!"#AA"#A!"#@A%"P-R`0Z8@P)$#J"#
M`F@.F(,"00Z0@P("W0H.F(,"0@Z@@P)%"S`````0!@``U*?__R`"````1@X0
MC`)(#AB&`T$.((,$1`XP`W$!"@X@00X800X00@X(2`L0````1`8``,"I__\0
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````\"D```````"P*0````````$`````````TP(````````!
M`````````.,"````````#```````````(`````````T`````````,&(`````
M```9`````````,C+````````&P`````````(`````````!H`````````T,L`
M```````<``````````@`````````]?[_;P````"P`P````````4`````````
M2`T````````&`````````)`$````````"@````````!D!`````````L`````
M````&``````````5`````````````````````P````````#8S0````````(`
M````````$`4````````4``````````<`````````%P````````!H%```````
M``<`````````Z!(````````(`````````(`!````````"0`````````8````
M`````!X`````````"`````````#[__]O``````$```@`````_O__;P````!H
M$@```````/___V\``````0````````#P__]O`````*P1````````^?__;P``
M```$````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MV,L`````````````````````````````,"````````!`(````````%`@````
M````8"````````!P(````````(`@````````D"````````"@(````````+`@
M````````P"````````#0(````````.`@````````\"``````````(0``````
M`!`A````````("$````````P(0```````$`A````````4"$```````!@(0``
M`````'`A````````@"$```````"0(0```````*`A````````L"$```````#`
M(0```````-`A````````X"$```````#P(0`````````B````````$"(`````
M```@(@```````#`B````````0"(```````!0(@```````&`B````````<"(`
M``````"`(@```````)`B````````H"(```````"P(@```````,`B````````
MT"(```````#@(@```````/`B`````````",````````0(P```````"`C````
M````,",```````!`(P```````%`C````````8",```````!P(P```````(`C
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````(T````````/____\`````V'(```````!'
M0T,Z("A58G5N='4@,3(N,BXP+3EU8G5N='4Q*2`Q,BXR+C```"YS:'-T<G1A
M8@`N:6YT97)P`"YN;W1E+F=N=2YP<F]P97)T>0`N;F]T92YG;G4N8G5I;&0M
M:60`+FYO=&4N04))+71A9P`N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG
M;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L82YD>6X`+G)E;&$N<&QT
M`"YI;FET`"YP;'0N9V]T`"YP;'0N<V5C`"YT97AT`"YF:6YI`"YR;V1A=&$`
M+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R
M87D`+F1Y;F%M:6,`+F1A=&$`+F)S<P`N8V]M;65N=```````````````````
M````````````````````````````````````````````````````````````
M``````````L````!`````@`````````8`P```````!@#````````'```````
M``````````````$````````````````````3````!P````(`````````.`,`
M```````X`P```````#`````````````````````(````````````````````
M)@````<````"`````````&@#````````:`,````````D````````````````
M````!````````````````````#D````'`````@````````",`P```````(P#
M````````(`````````````````````0```````````````````!'````]O__
M;P(`````````L`,```````"P`P```````-P`````````!@`````````(````
M````````````````40````L````"`````````)`$````````D`0```````"X
M"`````````<````!````"``````````8`````````%D````#`````@``````
M``!(#0```````$@-````````9`0```````````````````$`````````````
M``````!A````____;P(`````````K!$```````"L$0```````+H`````````
M!@`````````"``````````(`````````;@```/[__V\"`````````&@2````
M````:!(```````"```````````<````!````"````````````````````'T`
M```$`````@````````#H$@```````.@2````````@`$````````&````````
M``@`````````&`````````"'````!````$(`````````:!0```````!H%```
M`````!`%````````!@```!@````(`````````!@`````````D0````$````&
M```````````@`````````"`````````;````````````````````!```````
M`````````````(P````!````!@`````````@(````````"`@````````<`,`
M`````````````````!``````````$`````````"7`````0````8`````````
MD",```````"0(P```````!`````````````````````0`````````!``````
M````H`````$````&`````````*`C````````H",```````!@`P``````````
M````````$``````````0`````````*D````!````!@``````````)P``````
M```G````````,#L``````````````````!````````````````````"O````
M`0````8`````````,&(````````P8@````````T````````````````````$
M````````````````````M0````$````"``````````!P`````````'``````
M```@00``````````````````$````````````````````+T````!`````@``
M```````@L0```````""Q````````]`````````````````````0`````````
M``````````#+`````0````(`````````&+(````````8L@```````%@&````
M```````````````(````````````````````U0````X````#`````````,C+
M````````R+L````````(````````````````````"``````````(````````
M`.$````/`````P````````#0RP```````-"[````````"```````````````
M``````@`````````"`````````#M````!@````,`````````V,L```````#8
MNP`````````"````````!P`````````(`````````!``````````FP````$`
M```#`````````-C-````````V+T````````H`@``````````````````"```
M```````(`````````/8````!`````P``````````T`````````#`````````
M(`````````````````````@```````````````````#\````"`````,`````
M````(-`````````@P````````"@````````````````````(````````````
M`````````0$```$````P````````````````````(,`````````E````````
M`````````````0`````````!``````````$````#````````````````````
L`````$7`````````"@$```````````````````$`````````````````````
